#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_FIVE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_FIVE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/five.hpp>

#endif
